@@ -1,7 +1,8 @@
 import python_framework.api.src.service.SqlAlchemyProxy as sap
-from python_framework.api.src.annotation.MethodWrapper import Function
+from python_helper import Function
 
 ERROR_LOG = 'ErrorLog'
+ACTUATOR_HEALTH = 'ActuatorHealth'
 MODEL = sap.getNewModel()
 
 @Function
